"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.setupSvelteKit = void 0;
const coc_nvim_1 = require("coc.nvim");
const generateFiles_1 = require("./generateFiles");
function setupSvelteKit(context) {
    let contextMenuEnabled = false;
    context.subscriptions.push(coc_nvim_1.workspace.onDidChangeConfiguration(() => {
        enableContextMenu();
    }));
    (0, generateFiles_1.addGenerateKitRouteFilesCommand)(context);
    enableContextMenu();
    async function enableContextMenu() {
        const config = getConfig();
        if (config === 'never') {
            return;
        }
        if (config === 'always') {
            // Force on. The condition is defined in the extension manifest
            contextMenuEnabled = true;
            return;
        }
        const enabled = await detect(20);
        if (enabled !== contextMenuEnabled) {
            contextMenuEnabled = enabled;
        }
    }
}
exports.setupSvelteKit = setupSvelteKit;
function getConfig() {
    return (coc_nvim_1.workspace
        .getConfiguration('svelte.ui.svelteKitFilesContextMenu')
        .get('enable') ?? 'auto');
}
async function detect(nrRetries) {
    const packageJsonList = await coc_nvim_1.workspace.findFiles('**/package.json', '**/node_modules/**');
    if (packageJsonList.length === 0 && nrRetries > 0) {
        // We assume that the user has not setup their project yet, so try again after a while
        await new Promise((resolve) => setTimeout(resolve, 10000));
        return detect(nrRetries - 1);
    }
    for (const fileUri of packageJsonList) {
        try {
            const text = await coc_nvim_1.workspace.readFile(fileUri.toString());
            const pkg = JSON.parse(text);
            const hasKit = Object.keys(pkg.devDependencies ?? {})
                .concat(Object.keys(pkg.dependencies ?? {}))
                .includes('@sveltejs/kit');
            if (hasKit) {
                return true;
            }
        }
        catch (error) {
            console.error(error);
        }
    }
    return false;
}
//# sourceMappingURL=index.js.map