"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.addFindComponentReferencesListener = void 0;
const coc_nvim_1 = require("coc.nvim");
async function addFindComponentReferencesListener(getLS, context) {
    const disposable = coc_nvim_1.commands.registerCommand('svelte.typescript.findComponentReferences', handler);
    context.subscriptions.push(disposable);
    async function handler(resource) {
        if (!resource) {
            const documentUriString = coc_nvim_1.window.activeTextEditor?.document.uri;
            resource = documentUriString ? coc_nvim_1.Uri.parse(documentUriString) : undefined;
        }
        if (!resource || resource.scheme !== 'file') {
            return;
        }
        const document = await coc_nvim_1.workspace.openTextDocument(resource);
        await coc_nvim_1.window.withProgress({
            title: 'Finding component references',
        }, async (_, token) => {
            const lsLocations = await getLS().sendRequest('$/getComponentReferences', document.uri.toString(), token);
            if (!lsLocations) {
                return;
            }
            await coc_nvim_1.commands.executeCommand('editor.action.showReferences', resource, coc_nvim_1.Position.create(0, 0), lsLocations.map((ref) => coc_nvim_1.Location.create(ref.uri, coc_nvim_1.Range.create(ref.range.start.line, ref.range.start.character, ref.range.end.line, ref.range.end.character))));
        });
    }
}
exports.addFindComponentReferencesListener = addFindComponentReferencesListener;
//# sourceMappingURL=findComponentReferences.js.map