"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.addFindFileReferencesListener = void 0;
const coc_nvim_1 = require("coc.nvim");
/**
 * adopted from https://github.com/microsoft/vscode/blob/5f3e9c120a4407de3e55465588ce788618526eb0/extensions/typescript-language-features/src/languageFeatures/fileReferences.ts
 */
async function addFindFileReferencesListener(getLS, context) {
    const disposable = coc_nvim_1.commands.registerCommand('svelte.typescript.findAllFileReferences', handler);
    context.subscriptions.push(disposable);
    async function handler(resource) {
        if (!resource) {
            const documentUriString = coc_nvim_1.window.activeTextEditor?.document.uri;
            resource = documentUriString ? coc_nvim_1.Uri.parse(documentUriString) : undefined;
        }
        if (!resource || resource.scheme !== 'file') {
            return;
        }
        const document = await coc_nvim_1.workspace.openTextDocument(resource);
        await coc_nvim_1.window.withProgress({
            title: 'Finding file references',
        }, async (_, token) => {
            const lsLocations = await getLS().sendRequest('$/getFileReferences', document.uri.toString(), token);
            if (!lsLocations) {
                return;
            }
            const config = coc_nvim_1.workspace.getConfiguration('references');
            const existingSetting = config.inspect('preferredLocation');
            await config.update('preferredLocation', 'view');
            try {
                await coc_nvim_1.commands.executeCommand('editor.action.showReferences', resource, coc_nvim_1.Position.create(0, 0), lsLocations.map((ref) => coc_nvim_1.Location.create(ref.uri, coc_nvim_1.Range.create(ref.range.start.line, ref.range.start.character, ref.range.end.line, ref.range.end.character))));
            }
            finally {
                await config.update('preferredLocation', existingSetting?.workspaceFolderValue ?? existingSetting?.workspaceValue);
            }
        });
    }
}
exports.addFindFileReferencesListener = addFindFileReferencesListener;
//# sourceMappingURL=findFileReferences.js.map